<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <!-- CSRF Token -->
    <meta name="csrf-token" content="{{ csrf_token() }}">

    <title>{{ config('app.name', 'Laravel') }} @isset($meta_title)- {{ $meta_title }}@endisset</title>

    <!-- Scripts -->
    <script src="{{ asset('js/app.js') }}" defer></script>

    <!-- Fonts -->
    <link rel="dns-prefetch" href="//fonts.gstatic.com">
    <link href="https://fonts.googleapis.com/css?family=Nunito" rel="stylesheet" type="text/css">

    <!-- Styles -->
    <link href="{{ asset('css/app.css') }}" rel="stylesheet">
    <style>
        /**
         * On users/_user.blade.php template it removed the
         * right border radius from the gravatar image.
         */
        .no-radius-right {
            border-bottom-right-radius: 0;
            border-top-right-radius: 0;
        }

        /**
         * It correctly aligns the language switcher button
         * on edit forms.
         */
        .algo-language-switcher > .dropdown > button {
            margin-bottom: 0;
            padding-bottom: 0;
            margin-top: -6px;
        }

        /**
         * It sets the correct padding for the language switcher
         * buttons on show pages.
         */
        .algo-language-button {
            padding: 0 0.5rem;
        }

        /**
         * It makes the markdown/html text wrap correctly on
         * show pages.
         */
        .algo-markdown pre {
            word-wrap: anywhere;
            white-space: normal;
            // background-color: #333;
            // color: white;
            // margin: 14px -20px;
            // padding: 20px;
        }
    </style>
</head>
<body>
    <div id="app">
        <nav class="navbar navbar-expand-md navbar-light bg-white shadow-sm">
            <div class="container">
                <a class="navbar-brand" href="{{ url('/') }}">
                    {{ config('app.name', 'Laravel') }}
                </a>
                <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="{{ __('Toggle navigation') }}">
                    <span class="navbar-toggler-icon"></span>
                </button>

                <div class="collapse navbar-collapse" id="navbarSupportedContent">
                    <!-- Left Side Of Navbar -->
                    <ul class="navbar-nav mr-auto">
                        @auth
                            @include('algo::layouts._nav-item', [
                                'text' => trans('algo::posts'),
                                'route' => 'algo.posts.index'
                            ])
                            @include('algo::layouts._nav-item', [
                                'text' => trans('algo::categories'),
                                'route' => 'algo.categories.index'
                            ])
                            @include('algo::layouts._nav-item', [
                                'text' => trans('algo::tags'),
                                'route' => 'algo.tags.index'
                            ])
                            @include('algo::layouts._nav-item', [
                                'text' => trans('algo::users'),
                                'route' => 'algo.users.index'
                            ])
                        @endauth
                    </ul>

                    <!-- Right Side Of Navbar -->
                    <ul class="navbar-nav ml-auto">
                        <!-- Authentication Links -->
                        @guest
                            <li class="nav-item">
                                <a class="nav-link" href="{{ route('login') }}">{{ __('Login') }}</a>
                            </li>
                            @if (Route::has('register'))
                                <li class="nav-item">
                                    <a class="nav-link" href="{{ route('register') }}">{{ __('Register') }}</a>
                                </li>
                            @endif
                        @else
                            <li class="nav-item dropdown">
                                <a id="navbarDropdown" class="nav-link dropdown-toggle" href="#" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false" v-pre>
                                    {{ Auth::user()->name }} <span class="caret"></span>
                                </a>

                                <div class="dropdown-menu dropdown-menu-right" aria-labelledby="navbarDropdown">
                                    <a class="dropdown-item" href="{{ route('logout') }}"
                                       onclick="event.preventDefault();
                                                     document.getElementById('logout-form').submit();">
                                        {{ __('Logout') }}
                                    </a>

                                    <form id="logout-form" action="{{ route('logout') }}" method="POST" style="display: none;">
                                        @csrf
                                    </form>
                                </div>
                            </li>
                        @endguest
                    </ul>
                </div>
            </div>
        </nav>

        <main class="py-4">
            @yield('content')
        </main>
    </div>


    <script>
        /**
         * It displays a confirmation dialog before deleting a model.
         * Upon positive confirmation it submits the related form.
         */
        let confirms = document.getElementsByClassName('js-confirm-delete');

        for (let i = 0; i < confirms.length; i++) {
            confirms[i].addEventListener("click", function(event) {
                event.preventDefault();

                let message = "{{ trans('algo::js_confirm_delete') }}";

                if(confirms[i].dataset.confirm !== undefined) {
                    message = confirms[i].dataset.confirm;
                }

                if (confirm(message)) {
                    document.getElementById('delete-form-' + confirms[i].dataset.id).submit();
                }
            });
        }
    </script>
</body>
</html>
