@extends('algo::layouts.app', [
    'meta_title' => 'Objave | Create'
])

@section('content')
<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-8">
            <div class="card">
                <div class="card-header">Uredi objavu

                    @languageSwitcher([
                        'model_id' => $post->id,
                        'resource_route_name' => 'posts'
                    ])

                </div>

                <div class="card-body">
                    @statusAlert

                    {{-- @include('admin.ui.bootstrap4.forms.tmp_errors') --}}

                    @form([
                        'action' =>route('algo.posts.update', $post->id),
                        'method' => 'PUT'
                    ])
                        @input([
                            'name' => 'title',
                            'label' => trans('algo::label_name'),
                            'placeholder' => trans('algo::placeholder_name'),
                            'value' => $post->title,
                            'required' => true
                        ])

                        @input([
                            'name' => 'slug',
                            'label' => trans('algo::label_slug'),
                            'placeholder' => trans('algo::placeholder_slug'),
                            'help' => trans('algo::leave_field_empty'),
                            'value' => $post->slug
                        ])

                        @input([
                            'name' => 'intro',
                            'label' => 'Ukratko',
                            'placeholder' => 'Upišite kratki opis objave',
                            'value' => $post->intro
                        ])

                        @textarea([
                            'name' => 'content',
                            'label' => 'Sadržaj',
                            'help' => 'Za pisanje sadržaja koristite Markdown sintaksu.',
                            'rows' => 7,
                            'value' => $post->content,
                            'required' => true
                        ])

                        @input([
                            'name' => 'video_link',
                            'label' => 'YouTube video link',
                            'placeholder' => 'https://',
                            'value' => $post->video_link
                        ])

                        @input([
                            'name' => 'published_at_date',
                            'label' => 'Datum objave',
                            'type' => 'date',
                            'value' => is_null($post->published_at) ? '' : $post->published_at->format('Y-m-d')
                        ])

                        @input([
                            'name' => 'published_at_time',
                            'label' => 'Vrijeme objave',
                            'type' => 'time',
                            'value' => is_null($post->published_at) ? '' : $post->published_at->format('H:i')
                        ])

                        @select([
                            'label' => 'Autor',
                            'name' => 'author_id',
                            'options' => $authors,
                            'placeholder' => 'Odaberite autora objave',
                            'selected' => $post->author->id,
                            'required' => true
                        ])

                        @select([
                            'label' => 'Kategorija',
                            'name' => 'category_id',
                            'options' => $categories,
                            'placeholder' => 'Odaberite kategoriju',
                            'selected' => $post->category->id,
                            'required' => true
                        ])

                        @select([
                            'label' => 'Oznake',
                            'name' => 'tags_list[]',
                            'options' => $tags,
                            'placeholder' => 'Odaberite oznake',
                            'multiple' => true,
                            'selected' => $post->tags->pluck('id')->toArray()
                        ])

                        @checkbox([
                            'label' => trans('algo::label_featured'),
                            'name' => 'featured',
                            'checked' => $post->featured
                        ])

                        @submit(['text' => trans('algo::edit')])
                        <a class="btn btn-link" href="{{route('algo.posts.show', $post->id) }}">{{ trans('algo::cancel') }}</a>
                    @endform
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
