<?php

namespace Laravelista\Algo\Controllers;

use Illuminate\Http\Request;
use Illuminate\Validation\Rule;
use Laravelista\Algo\Models\Category;
use Laravelista\Algo\Helpers\ValidateLocale;
use Laravelista\Algo\Helpers\Slug;

class CategoryTranslationController extends Controller
{
    protected $validateLocale;

    public function __construct(ValidateLocale $validateLocale)
    {
        $this->validateLocale = $validateLocale;
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Category $category
     * @param string $locale
     * @return \Illuminate\Http\Response
     */
    public function edit(Category $category, $locale)
    {
        $this->validateLocale->validate($locale);

        return view('algo::categories.translations')
            ->withCategory($category)
            ->withLocale($locale);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param Category $category
     * @param string $locale
     * @param Slug $slug
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Category $category, $locale, Slug $slug)
    {
        $this->validateLocale->validate($locale);

        $validatedData = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'slug' => [
                'nullable', 'string', 'max:255',
                Rule::unique('category_translations')
                    ->ignore($category->id, 'category_id')
                    ->where('locale', $locale)
            ],
            'description' => ['nullable', 'string'],
        ]);

        $category->translateOrNew($locale)->name = $validatedData['name'];
        $category->translateOrNew($locale)->slug = $slug->get($validatedData['slug'], $validatedData['name']);
        $category->translateOrNew($locale)->description = $validatedData['description'];
        $category->save();

        return redirect()
            ->route('algo.categories.translations.edit', [
                $category->id, $locale
            ])
            ->with('status', 'Kategorija prevedena!');
    }
}
